==> wxmaxima_18.02.0.orig.tar.gz: wxmaxima-Version-18.02.0/src/LimitCell.h <==
﻿// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
//
//  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
//            (C) 2014-2016 Gunter Königsmann <wxMaxima@physikbuch.de>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//

/*! \file
  This file declares the class LimitCell

  LimitCell is the MathCell type that represents maxima's <code>limit()</code> command.
*/

#ifndef LIMITCELL_H
#define LIMITCELL_H

#include "MathCell.h"

class LimitCell : public MathCell
{
public:
  LimitCell(MathCell *parent, Configuration **config, CellPointers *cellPointers);

  ~LimitCell();

  std::list<MathCell *> GetInnerCells();

  MathCell *Copy();

  void RecalculateHeight(int fontsize);

  void RecalculateWidths(int fontsize);

  void Draw(wxPoint point, int fontsize);

  void SetBase(MathCell *base);

  void SetUnder(MathCell *under);

  void SetName(MathCell *name);

  wxString ToString();

  wxString ToTeX();

  wxString ToXML();

  wxString ToOMML();

  wxString ToMathML();

  void SetGroup(MathCell *parent);

protected:
  MathCell *m_base;
  MathCell *m_under;
  MathCell *m_name;
};

#endif // LIMITCELL_H

==> wxmaxima_18.11.4.orig.tar.gz: wxmaxima-Version-18.11.4/src/LimitCell.h <==
﻿// -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
//
//  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
//            (C) 2014-2016 Gunter Königsmann <wxMaxima@physikbuch.de>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  SPDX-License-Identifier: GPL-2.0+

/*! \file
  This file declares the class LimitCell

  LimitCell is the MathCell type that represents maxima's <code>limit()</code> command.
*/

#ifndef LIMITCELL_H
#define LIMITCELL_H

#include "MathCell.h"
#include "TextCell.h"

class LimitCell : public MathCell
{
public:
  LimitCell(MathCell *parent, Configuration **config, CellPointers *cellPointers);

  ~LimitCell();

  std::list<MathCell *> GetInnerCells();

  MathCell *Copy();

  void RecalculateHeight(int fontsize);

  void RecalculateWidths(int fontsize);

  virtual void Draw(wxPoint point);

  void SetBase(MathCell *base);

  void SetUnder(MathCell *under);

  void SetName(MathCell *name);

  wxString ToString();

  wxString ToTeX();

  wxString ToXML();

  wxString ToOMML();

  wxString ToMathML();

  void SetGroup(MathCell *parent);
  void Unbreak();
  bool BreakUp();

protected:
  MathCell *m_name;
  TextCell *m_open;
  MathCell *m_base;
  TextCell *m_comma;
  MathCell *m_under;
  TextCell *m_close;
  MathCell *m_name_last;
  MathCell *m_base_last;
  MathCell *m_under_last;
};

#endif // LIMITCELL_H
